.. -*- mode: rst -*-

PyHRF
=====

.. image:: https://img.shields.io/pypi/v/pyhrf.svg
    :target: https://pypi.python.org/pypi/pyhrf

.. image:: https://img.shields.io/travis/pyhrf/pyhrf/master.svg
    :target: https://travis-ci.org/pyhrf/pyhrf

.. image:: https://readthedocs.org/projects/pyhrf/badge/?version=latest
    :target: http://pyhrf.readthedocs.io/en/latest

.. image:: https://img.shields.io/coveralls/pyhrf/pyhrf/master.svg
    :target: https://coveralls.io/r/pyhrf/pyhrf?branch=master

.. image:: https://img.shields.io/gitter/room/pyhrf/pyhrf.svg
    :target:  https://gitter.im/pyhrf/pyhrf

.. contents::

What is PyHRF?
**************

PyHRF is a set of tools to analyze fMRI data and specifically study hemodynamics.


Installation
************

For installation instructions, see `installation website <http://www.pyhrf.org/installation.html>`_.

Documentation
*************

PyHRF documentation is available on the web:

    http://www.pyhrf.org/manual.html

Website
*******

The PyHRF site is:

    http://www.pyhrf.org/

Bug reports
***********

To search for bugs or report them, please use the PyHRF Bug Tracker at:

    https://github.com/pyhrf/pyhrf/issues

License information
*******************

PyHRF is under the CeCILL v2. See the file ``LICENCE`` for details.
